@@ -32,7 +32,12 @@
 #include <libsoup/soup.h>
 
 #ifdef GDK_WINDOWING_X11
-#include <gtk/gtkx.h>
+#include <gdk/gdkx.h>
+#endif
+#ifdef GDK_WINDOWING_WAYLAND
+#if GTK_CHECK_VERSION(3,22,4)
+#include <gdk/gdkwayland.h>
+#endif
 #endif
 
 #ifdef HAVE_PACKAGEKIT
@@ -320,10 +325,13 @@ gs_application_initialize_ui (GsApplication *app)
 
 	gs_shell_setup (app->shell, app->plugin_loader, app->cancellable);
 	gtk_application_add_window (GTK_APPLICATION (app), gs_shell_get_window (app->shell));
+
+	/* monitor the network as the many UI operations need the network */
+	gs_application_monitor_network (app);
 }
 
 static void
-initialize_ui_and_present_window (GsApplication *app)
+initialize_ui_and_present_window (GsApplication *app, const gchar *startup_id)
 {
 	GList *windows;
 	GtkWindow *window;
@@ -332,6 +340,9 @@ initialize_ui_and_present_window (GsApplication *app)
 	windows = gtk_application_get_windows (GTK_APPLICATION (app));
 	if (windows) {
 		window = windows->data;
+
+		if (startup_id != NULL)
+			gtk_window_set_startup_id (window, startup_id);
 		gtk_window_present (window);
 	}
 }
@@ -541,7 +552,7 @@ set_mode_activated (GSimpleAction *action,
 	GsApplication *app = GS_APPLICATION (data);
 	const gchar *mode;
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, NULL);
 
 	mode = g_variant_get_string (parameter, NULL);
 	if (g_strcmp0 (mode, "updates") == 0) {
@@ -568,7 +579,7 @@ search_activated (GSimpleAction *action,
 	GsApplication *app = GS_APPLICATION (data);
 	const gchar *search;
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, NULL);
 
 	search = g_variant_get_string (parameter, NULL);
 	gs_shell_show_search (app->shell, search);
@@ -583,7 +594,7 @@ details_activated (GSimpleAction *action,
 	const gchar *id;
 	const gchar *search;
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, NULL);
 
 	g_variant_get (parameter, "(&s&s)", &id, &search);
 	if (search != NULL && search[0] != '\0')
@@ -608,7 +619,7 @@ details_pkg_activated (GSimpleAction *action,
 	GsApplication *app = GS_APPLICATION (data);
 	g_autoptr (GsApp) a = NULL;
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, NULL);
 
 	a = gs_app_new (NULL);
 	gs_app_add_source (a, g_variant_get_string (parameter, NULL));
@@ -624,7 +635,6 @@ filename_activated (GSimpleAction *action,
 	const gchar *filename;
 
 	gs_application_initialize_ui (app);
-	gs_application_monitor_network (GS_APPLICATION (app));
 
 	g_variant_get (parameter, "(&s)", &filename);
 	gs_shell_show_filename (app->shell, filename);
@@ -662,7 +672,7 @@ show_offline_updates_error (GSimpleAction *action,
 {
 	GsApplication *app = GS_APPLICATION (data);
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, NULL);
 
 	gs_shell_set_mode (app->shell, GS_SHELL_MODE_UPDATES);
 	gs_update_monitor_show_error (app->update_monitor, app->shell);
@@ -674,26 +684,32 @@ install_resources_activated (GSimpleAction *action,
                              gpointer       data)
 {
 	GsApplication *app = GS_APPLICATION (data);
-#ifdef GDK_WINDOWING_X11
 	GdkDisplay *display;
-#endif
 	const gchar *mode;
 	const gchar *startup_id;
 	g_autofree gchar **resources = NULL;
 
 	g_variant_get (parameter, "(&s^a&s&s)", &mode, &resources, &startup_id);
 
-#ifdef GDK_WINDOWING_X11
 	display = gdk_display_get_default ();
-
+#ifdef GDK_WINDOWING_X11
 	if (GDK_IS_X11_DISPLAY (display)) {
 		if (startup_id != NULL && startup_id[0] != '\0')
 			gdk_x11_display_set_startup_notification_id (display,
 			                                             startup_id);
 	}
+#endif
+#ifdef GDK_WINDOWING_WAYLAND
+#if GTK_CHECK_VERSION(3,22,4)
+	if (GDK_IS_WAYLAND_DISPLAY (display)) {
+		if (startup_id != NULL && startup_id[0] != '\0')
+			gdk_wayland_display_set_startup_notification_id (display,
+			                                                 startup_id);
+	}
+#endif
 #endif
 
-	initialize_ui_and_present_window (app);
+	initialize_ui_and_present_window (app, startup_id);
 
 	gs_shell_show_extras_search (app->shell, mode, resources);
 }
@@ -777,7 +793,6 @@ gs_application_activate (GApplication *application)
 	GsApplication *app = GS_APPLICATION (application);
 
 	gs_application_initialize_ui (GS_APPLICATION (application));
-	gs_application_monitor_network (GS_APPLICATION (application));
 
 	/* start metadata loading screen */
 	if (gs_shell_get_mode (app->shell) == GS_SHELL_MODE_UNKNOWN) {
