@@ -47,6 +47,7 @@
 #include <gio/gdesktopappinfo.h>
 #include <gdk/gdk.h>
 
+#include "gs-app-list-private.h"
 #include "gs-os-release.h"
 #include "gs-plugin-private.h"
 #include "gs-plugin.h"
@@ -1207,10 +1208,42 @@ gs_plugin_cache_lookup (GsPlugin *plugin, const gchar *key)
 	return g_object_ref (app);
 }
 
+/**
+ * gs_plugin_cache_remove:
+ * @plugin: a #GsPlugin
+ * @key: a key which matches
+ *
+ * Removes an application from the per-plugin cache.
+ *
+ * Since: 3.22
+ **/
+void
+gs_plugin_cache_remove (GsPlugin *plugin, const gchar *key)
+{
+	GsPluginPrivate *priv = gs_plugin_get_instance_private (plugin);
+
+	g_return_if_fail (GS_IS_PLUGIN (plugin));
+	g_return_if_fail (key != NULL);
+
+	/* global, so using internal unique_id */
+	if (gs_plugin_has_flags (plugin, GS_PLUGIN_FLAGS_GLOBAL_CACHE)) {
+		GsApp *app_tmp;
+		if (!as_utils_unique_id_valid (key)) {
+			g_critical ("key %s is not a unique_id", key);
+			return;
+		}
+		app_tmp = gs_app_list_lookup (priv->global_cache, key);
+		if (app_tmp != NULL)
+			gs_app_list_remove (priv->global_cache, app_tmp);
+		return;
+	}
+	g_hash_table_remove (priv->cache, key);
+}
+
 /**
  * gs_plugin_cache_add:
  * @plugin: a #GsPlugin
- * @key: a string
+ * @key: a string, or %NULL if the unique ID should be used
  * @app: a #GsApp
  *
  * Adds an application to the per-plugin cache. This is optional,
@@ -1225,9 +1258,12 @@ gs_plugin_cache_add (GsPlugin *plugin, const gchar *key, GsApp *app)
 	g_autoptr(GMutexLocker) locker = g_mutex_locker_new (&priv->cache_mutex);
 
 	g_return_if_fail (GS_IS_PLUGIN (plugin));
-	g_return_if_fail (key != NULL);
 	g_return_if_fail (GS_IS_APP (app));
 
+	/* default */
+	if (key == NULL)
+		key = gs_app_get_unique_id (app);
+
 	/* global, so using internal unique_id */
 	if (gs_plugin_has_flags (plugin, GS_PLUGIN_FLAGS_GLOBAL_CACHE)) {
 		if (!as_utils_unique_id_valid (key)) {
@@ -1314,6 +1350,90 @@ gs_plugin_error_to_string (GsPluginError error)
 	return NULL;
 }
 
+/**
+ * gs_plugin_action_to_string:
+ * @action: a #GsPluginAction, e.g. %GS_PLUGIN_ERROR_NO_NETWORK
+ *
+ * Converts the enumerated action to a string.
+ *
+ * Returns: a string, or %NULL for invalid
+ **/
+const gchar *
+gs_plugin_action_to_string (GsPluginAction action)
+{
+	if (action == GS_PLUGIN_ACTION_INSTALL)
+		return "install";
+	if (action == GS_PLUGIN_ACTION_REMOVE)
+		return "remove";
+	if (action == GS_PLUGIN_ACTION_UPDATE)
+		return "update";
+	if (action == GS_PLUGIN_ACTION_SET_RATING)
+		return "set-rating";
+	if (action == GS_PLUGIN_ACTION_UPGRADE_DOWNLOAD)
+		return "upgrade-download";
+	if (action == GS_PLUGIN_ACTION_UPGRADE_TRIGGER)
+		return "upgrade-trigger";
+	if (action == GS_PLUGIN_ACTION_LAUNCH)
+		return "launch";
+	if (action == GS_PLUGIN_ACTION_UPDATE_CANCEL)
+		return "update-cancel";
+	if (action == GS_PLUGIN_ACTION_ADD_SHORTCUT)
+		return "add-shortcut";
+	if (action == GS_PLUGIN_ACTION_REMOVE_SHORTCUT)
+		return "remove-shortcut";
+	if (action == GS_PLUGIN_ACTION_REVIEW_SUBMIT)
+		return "review-submit";
+	if (action == GS_PLUGIN_ACTION_REVIEW_UPVOTE)
+		return "review-upvote";
+	if (action == GS_PLUGIN_ACTION_REVIEW_DOWNVOTE)
+		return "review-downvote";
+	if (action == GS_PLUGIN_ACTION_REVIEW_REPORT)
+		return "review-report";
+	if (action == GS_PLUGIN_ACTION_REVIEW_REMOVE)
+		return "review-remove";
+	if (action == GS_PLUGIN_ACTION_REVIEW_DISMISS)
+		return "review-dismiss";
+	if (action == GS_PLUGIN_ACTION_GET_UPDATES)
+		return "get-updates";
+	if (action == GS_PLUGIN_ACTION_GET_DISTRO_UPDATES)
+		return "get-distro-updates";
+	if (action == GS_PLUGIN_ACTION_GET_UNVOTED_REVIEWS)
+		return "get-unvoted-reviews";
+	if (action == GS_PLUGIN_ACTION_GET_SOURCES)
+		return "get-sources";
+	if (action == GS_PLUGIN_ACTION_GET_INSTALLED)
+		return "get-installed";
+	if (action == GS_PLUGIN_ACTION_GET_POPULAR)
+		return "get-popular";
+	if (action == GS_PLUGIN_ACTION_GET_FEATURED)
+		return "get-featured";
+	if (action == GS_PLUGIN_ACTION_SEARCH)
+		return "search";
+	if (action == GS_PLUGIN_ACTION_SEARCH_FILES)
+		return "search-files";
+	if (action == GS_PLUGIN_ACTION_SEARCH_PROVIDES)
+		return "search-provides";
+	if (action == GS_PLUGIN_ACTION_GET_CATEGORIES)
+		return "get-categories";
+	if (action == GS_PLUGIN_ACTION_GET_CATEGORY_APPS)
+		return "get-category-apps";
+	if (action == GS_PLUGIN_ACTION_REFINE)
+		return "refine";
+	if (action == GS_PLUGIN_ACTION_REFRESH)
+		return "refresh";
+	if (action == GS_PLUGIN_ACTION_FILE_TO_APP)
+		return "file-to-app";
+	if (action == GS_PLUGIN_ACTION_AUTH_LOGIN)
+		return "auth-login";
+	if (action == GS_PLUGIN_ACTION_AUTH_LOGOUT)
+		return "auth-logout";
+	if (action == GS_PLUGIN_ACTION_AUTH_REGISTER)
+		return "auth-register";
+	if (action == GS_PLUGIN_ACTION_AUTH_LOST_PASSWORD)
+		return "auth-lost-password";
+	return NULL;
+}
+
 static void
 gs_plugin_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
@@ -1392,17 +1512,10 @@ gs_plugin_init (GsPlugin *plugin)
 	priv->enabled = TRUE;
 	priv->scale = 1;
 	priv->profile = as_profile_new ();
-#if AS_CHECK_VERSION(0,6,2)
 	priv->cache = g_hash_table_new_full ((GHashFunc) as_utils_unique_id_hash,
 					     (GEqualFunc) as_utils_unique_id_equal,
 					     g_free,
 					     (GDestroyNotify) g_object_unref);
-#else
-	priv->cache = g_hash_table_new_full (g_str_hash,
-					     g_str_equal,
-					     g_free,
-					     (GDestroyNotify) g_object_unref);
-#endif
 	g_mutex_init (&priv->cache_mutex);
 	g_mutex_init (&priv->timer_mutex);
 	g_rw_lock_init (&priv->rwlock);
