@@ -113,6 +113,10 @@ gs_plugin_flatpak_changed_cb (GFileMonitor *monitor,
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GError) error_md = NULL;
 
+	/* don't refresh when it's us ourselves doing the change */
+	if (gs_plugin_has_flags (self->plugin, GS_PLUGIN_FLAGS_RUNNING_SELF))
+		return;
+
 	/* manually drop the cache */
 	if (!flatpak_installation_drop_caches (self->installation,
 					       NULL, &error)) {
@@ -1025,6 +1029,10 @@ gs_plugin_refine_item_origin_hostname (GsFlatpak *self, GsApp *app,
 	if (gs_app_get_origin_hostname (app) != NULL)
 		return TRUE;
 
+	/* no origin */
+	if (gs_app_get_origin (app) == NULL)
+		return TRUE;
+
 	/* get the remote  */
 	xremote = flatpak_installation_get_remote_by_name (self->installation,
 							   gs_app_get_origin (app),
@@ -1470,6 +1478,16 @@ gs_plugin_refine_item_metadata (GsFlatpak *self,
 	} else {
 		g_autoptr(FlatpakRef) xref = NULL;
 
+		/* no origin */
+		if (gs_app_get_origin (app) == NULL) {
+			g_set_error (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "no origin set for %s",
+				     gs_app_get_unique_id (app));
+			return FALSE;
+		}
+
 		/* fetch from the server */
 		xref = gs_flatpak_create_fake_ref (app, error);
 		if (xref == NULL)
@@ -1584,6 +1602,16 @@ gs_plugin_refine_item_size (GsFlatpak *self,
 	} else {
 		g_autoptr(FlatpakRef) xref = NULL;
 		g_autoptr(GError) error_local = NULL;
+
+		/* no origin */
+		if (gs_app_get_origin (app) == NULL) {
+			g_set_error (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "no origin set for %s",
+				     gs_app_get_unique_id (app));
+			return FALSE;
+		}
 		xref = gs_flatpak_create_fake_ref (app, error);
 		if (xref == NULL)
 			return FALSE;
@@ -1952,6 +1980,15 @@ gs_flatpak_app_install (GsFlatpak *self,
 							    app,
 							    cancellable, error);
 	} else {
+		/* no origin */
+		if (gs_app_get_origin (app) == NULL) {
+			g_set_error (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "no origin set for %s",
+				     gs_app_get_unique_id (app));
+			return FALSE;
+		}
 		g_debug ("installing %s", gs_app_get_id (app));
 		xref = flatpak_installation_install (self->installation,
 						     gs_app_get_origin (app),
