@@ -252,9 +252,17 @@ gs_plugin_packagekit_resolve_packages (GsPlugin *plugin,
 		sources = gs_app_get_sources (app);
 		for (j = 0; j < sources->len; j++) {
 			pkgname = g_ptr_array_index (sources, j);
+			if (pkgname == NULL || pkgname[0] == '\0') {
+				g_warning ("invalid pkgname '%s' for %s",
+					   pkgname,
+					   gs_app_get_unique_id (app));
+				continue;
+			}
 			g_ptr_array_add (package_ids, g_strdup (pkgname));
 		}
 	}
+	if (package_ids->len == 0)
+		return TRUE;
 	g_ptr_array_add (package_ids, NULL);
 
 	data.app = NULL;
@@ -477,7 +485,7 @@ gs_plugin_packagekit_refine_details_app (GsPlugin *plugin,
 	}
 
 	/* the size is the size of all sources */
-	if (gs_app_get_state (app) == AS_APP_STATE_INSTALLED) {
+	if (gs_app_is_installed (app)) {
 		gs_app_set_size_download (app, GS_APP_SIZE_UNKNOWABLE);
 		if (size > 0 && gs_app_get_size_installed (app) == 0)
 			gs_app_set_size_installed (app, size);
@@ -573,6 +581,8 @@ gs_plugin_packagekit_refine_update_urgency (GsPlugin *plugin,
 	for (i = 0; i < gs_app_list_length (list); i++) {
 		g_autoptr (PkPackage) pkg = NULL;
 		app = gs_app_list_index (list, i);
+		if (gs_app_has_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX))
+			continue;
 		package_id = gs_app_get_source_id_default (app);
 		if (package_id == NULL)
 			continue;
@@ -642,6 +652,8 @@ gs_plugin_refine_require_details (GsPlugin *plugin,
 	list_tmp = gs_app_list_new ();
 	for (i = 0; i < gs_app_list_length (list); i++) {
 		app = gs_app_list_index (list, i);
+		if (gs_app_has_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX))
+			continue;
 		if (gs_app_get_kind (app) == AS_APP_KIND_WEB_APP)
 			continue;
 		if (g_strcmp0 (gs_app_get_management_plugin (app), "packagekit") != 0)
@@ -814,6 +826,8 @@ gs_plugin_refine (GsPlugin *plugin,
 	resolve_all = gs_app_list_new ();
 	for (i = 0; i < gs_app_list_length (list); i++) {
 		app = gs_app_list_index (list, i);
+		if (gs_app_has_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX))
+			continue;
 		if (gs_app_get_kind (app) == AS_APP_KIND_WEB_APP)
 			continue;
 		tmp = gs_app_get_management_plugin (app);
@@ -850,6 +864,8 @@ gs_plugin_refine (GsPlugin *plugin,
 		if ((flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_SETUP_ACTION) == 0)
 			continue;
 		app = gs_app_list_index (list, i);
+		if (gs_app_has_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX))
+			continue;
 		if (gs_app_get_source_id_default (app) != NULL)
 			continue;
 		tmp = gs_app_get_management_plugin (app);
@@ -890,6 +906,8 @@ gs_plugin_refine (GsPlugin *plugin,
 	updatedetails_all = gs_app_list_new ();
 	for (i = 0; i < gs_app_list_length (list); i++) {
 		app = gs_app_list_index (list, i);
+		if (gs_app_has_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX))
+			continue;
 		if (gs_app_get_state (app) != AS_APP_STATE_UPDATABLE)
 			continue;
 		tmp = gs_app_get_management_plugin (app);
